@@ -1,8 +1,6 @@
-# $Id$
+# $Id: Size.pm,v 1.11 2006/06/08 06:43:20 comdog Exp $
 package HTTP::Size;
 use strict;
-use warnings;
-no warnings;
 
 =head1 NAME
 
@@ -64,7 +62,7 @@ use LWP::UserAgent;
 use URI;
 use HTTP::Request;
 
-$VERSION = '1.13_01';
+$VERSION = sprintf "%d.%02d", q$Revision: 1.11 $ =~ m/ (\d+) \. (\d+) /xg;
 
 my $User_agent = LWP::UserAgent->new();
 
@@ -266,12 +264,11 @@ members of the project can shepherd this module appropriately.
 
 brian d foy, C<< <bdfoy@cpan.org> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-Copyright (c) 2000-2007 brian d foy.  All rights reserved.
+Copyright (c) 2000-2006, brian d foy, All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
